# Note to packagers:
# libei-the-repo comes with three libraries, all independent of each other and
# processes that use one may not use the other.
# Here there are packaged as libei, libeis and liboeffis plus respective subpackages.
%global major    1
%define libname  %mklibname ei %major
%define libnames %mklibname eis %major
%define libnameo %mklibname oei %major
%define devname  %mklibname ei -d
%define devnames %mklibname eis -d
%define devnameo %mklibname oei -d

Name:           libei
Version:        1.4.0
Release:        %mkrel 2
Summary:        Library for Emulated Input
Group:          System/Libraries

License:        MIT
URL:            https://gitlab.freedesktop.org/libinput/libei
Source0:        https://gitlab.freedesktop.org/libinput/libei/-/archive/%{version}/libei-%{version}.tar.bz2

BuildRequires:  gcc
BuildRequires:  git-core
BuildRequires:  libxml2
BuildRequires:  meson
BuildRequires:  pkgconf-pkg-config
BuildRequires:  python3
BuildRequires:  python3-attrs
BuildRequires:  python3-jinja2
BuildRequires:  python3-rpm-macros
BuildRequires:  systemd-devel

# libei packages
%description
libei is a library to Emulate Input. It allows clients to talk to
an EIS implementatation (Emulated Input Server), typically a Wayland compositor
and send input events via that connection. The EIS implementation
replays those events as if they came from physical devices.

%package -n %libname
Group:          System/Libraries
Summary:        Library for Emulated Input Servers

%description -n %libname
libei is a library to Emulate Input. It allows clients to talk to
an EIS implementatation (Emulated Input Server), typically a Wayland compositor
and send input events via that connection. The EIS implementation
replays those events as if they came from physical devices.

%package -n %devname
Group:          Development/C
Summary:        Library for Emulated Input Development Package
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %devname
Library for Emulated Input Development Package.

%package utils
Summary:        Library for Emulated Input Utilities Package
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}

%description utils
Utilities to test and/or debug emulated input devices.

# libeis packages
%package -n %libnames
Group:          System/Libraries
Summary:        Library for Emulated Input Servers

%description -n %libnames
libeis is a library to provide logical devices that other applications
can then use to emulate input. This library is typically used by
a Wayland compositor that provides an EIS implementation.

%package -n %devnames
Group:          Development/C
Summary:        Library for Emulated Input Serverse Development Package
Requires:       %{libnames} = %{version}-%{release}
Provides:       libeis-devel = %{version}-%{release}

%description -n %devnames
Library for Emulated Input Servers Development Package.

# liboeffis packages
%package -n %libnameo
Summary:        Library for XDG RemoteDesktop Portal Setup
Group:          System/Libraries

%description -n %libnameo
liboeffis is a helper library to contact the XDG RemoteDesktop portal
and obtain an EIS socket through the portal.

%package -n %devnameo
Summary:        Library for XDG RemoteDesktop Portal Setup Development Package
Group:          Development/C
Requires:       %{libnameo} = %{version}-%{release}
Provides:       liboei-devel = %{version}-%{release}

%description -n %devnameo
Library for XDG RemoteDesktop Portal Setup Development Package.

%prep
%autosetup -S git
# Replace whatever the source uses with the approved call
%py3_shebang_fix $(git grep -l  '#!/usr/bin/.*python3')

%build
%meson -Dtests=disabled -Ddocumentation='[]' -Dliboeffis=enabled
%meson_build

%install
%meson_install

%files -n %libname
%license COPYING
%{_libdir}/libei.so.%{major}{,.*}

%files -n %libnames
%license COPYING
%{_libdir}/libeis.so.%{major}{,.*}

%files -n %libnameo
%license COPYING
%{_libdir}/liboeffis.so.%{major}{,.*}

%files -n %devname
%dir %{_includedir}/libei-1.0/
%{_includedir}/libei-1.0/libei.h
%{_libdir}/libei.so
%{_libdir}/pkgconfig/libei-1.0.pc

%files -n %devnames
%dir %{_includedir}/libei-1.0/
%{_includedir}/libei-1.0/libeis.h
%{_libdir}/libeis.so
%{_libdir}/pkgconfig/libeis-1.0.pc

%files -n %devnameo
%dir %{_includedir}/libei-1.0/
%{_includedir}/libei-1.0/liboeffis.h
%{_libdir}/liboeffis.so
%{_libdir}/pkgconfig/liboeffis-1.0.pc

%files utils
%{_bindir}/ei-debug-events



%changelog
* Mon Jul 07 2025 umeabot <umeabot> 1.4.0-2.mga10
+ Revision: 2248791
- Mageia 10 Mass Rebuild

* Wed Mar 19 2025 daviddavid <daviddavid> 1.4.0-1.mga10
+ Revision: 2166738
- new version 1.4.0

* Thu Aug 08 2024 daviddavid <daviddavid> 1.3.0-1.mga10
+ Revision: 2084110
- new version: 1.3.0

* Mon Mar 18 2024 daviddavid <daviddavid> 1.2.1-1.mga10
+ Revision: 2050524
- new version 1.2.1

* Thu Sep 28 2023 tv <tv> 1.1.0-2.mga10
+ Revision: 1992014
- libei-devel should requires libei instead of libeis

* Wed Sep 27 2023 tv <tv> 1.1.0-1.mga10
+ Revision: 1991381
- imported package libei


* Wed Sep 27 2023 Thierry Vignaud <tv@mageia.org> 1.1.0-1.mga10
- Import from FC

* Thu Sep 07 2023 Kalev Lember <klember@redhat.com> - 1.1.0-2
- Rebuild

* Thu Sep 07 2023 Peter Hutterer <peter.hutterer@redhat.com> - 1.1.0-1
- libei 1.1.0

* Thu Aug 31 2023 Peter Hutterer <peter.hutterer@redhat.com> - 1.0.901-1
- libei 1.0.901

* Thu Jul 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Thu Jun 08 2023 Peter Hutterer <peter.hutterer@redhat.com> - 1.0.0-1
- libei 1.0.0

* Tue May 23 2023 Peter Hutterer <peter.hutterer@redhat.com> - 0.99.2-1
- libei 0.99.2

* Wed May 17 2023 Peter Hutterer <peter.hutterer@redhat.com> - 0.99.1-1
- Initial package (#2207838)
